@@ -17,8 +17,13 @@ class AtlassianRestAPI(object):
     form_token_headers = {'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
                           'X-Atlassian-Token': 'no-check'}
 
+    response = None
+
     def __init__(self, url, username=None, password=None, timeout=60, api_root='rest/api', api_version='latest',
                  verify_ssl=True, session=None, oauth=None, cookies=None, advanced_mode=None):
+
+        if ('atlassin.net' in url or 'jira.com' in url) and '/wiki' not in url:
+            url = self.url_joiner(url, '/wiki')
         self.url = url
         self.username = username
         self.password = password
@@ -119,8 +124,9 @@ class AtlassianRestAPI(object):
             timeout=self.timeout,
             verify=self.verify_ssl,
             files=files
-        )       
+        )
         if self.advanced_mode:
+            self.response = response
             return response
         try:
             if response.text:
